pub struct HttpProxy { /* private fields */ }Expand description
A storage backend driver to access blobs through a http proxy server.
The http proxy server may be local (using unix socket) or be remote (using http:// or https://).
HttpProxy uses two API endpoints to access the blobs:
HEAD /path/to/blobto get the blob sizeGET /path/to/blobto read the blob
The http proxy server should respect the Range header to support range reading.
Implementations