BlobRangeMap

Struct BlobRangeMap 

pub struct BlobRangeMap { /* private fields */ }
An implementation of RangeMap to support cache state tracking by using a bitmap file.

The BlobRangeMap is an implementation of RangeMap which uses a bitmap file and atomic bitmap operations to track readiness state. It creates or opens a file with the name $blob_id.range_map to record whether a data range has been cached by the blob cache, and atomic bitmap operations are used to manipulate the state bit. The bitmap file will be persisted to disk.

Implementations

Source

impl BlobRangeMap

pub fn new(blob_path: &str, count: u32, shift: u32) -> Result<Self>

Create a new instance of BlobRangeMap.

pub fn open( blob_id: &str, workdir: &str, count: u32, shift: u32, ) -> Result<Self>

Create a new instance of BlobRangeMap from an existing chunk map file.