BlobStateMap

Struct BlobStateMap 

pub struct BlobStateMap<C, I> { /* private fields */ }
Adapter structure to enable concurrent chunk readiness manipulating based on a base ChunkMap object.

A base ChunkMap, such as IndexedChunkMap, only tracks chunk readiness state, but doesn’t support concurrent manipulating of the chunk readiness state. The BlobStateMap structure acts as an adapter to enable concurrent chunk readiness state manipulation.

Implementations

Source

impl BlobStateMap<BlobRangeMap, u64>

pub fn from_range_map(map: BlobRangeMap) -> Self

Create a new instance of BlobStateMap from a BlobRangeMap object.