pub struct DummyCacheMgr { /* private fields */ }Expand description
A dummy implementation of BlobCacheMgr, simply reporting each chunk as cached or not cached according to configuration.
The DummyCacheMgr is a dummy implementation of the BlobCacheMgr, which doesn’t really cache
data. Instead it just reads data from the backend, uncompressed it if needed and then pass on
the data to the clients.
Implementations
Sourceimpl DummyCacheMgr
impl DummyCacheMgr
Sourcepub fn new(
config: &CacheConfigV2,
backend: Arc<dyn BlobBackend>,
cached: bool,
) -> Result<DummyCacheMgr>
pub fn new( config: &CacheConfigV2, backend: Arc<dyn BlobBackend>, cached: bool, ) -> Result<DummyCacheMgr>
Create a new instance of DummyCacheMgr.