pub struct BlobFeatures { /* private fields */ }Expand description
Features bits for blob management.
Implementations
Sourceimpl BlobFeatures
impl BlobFeatures
Sourcepub const INLINED_FS_META: Self
pub const INLINED_FS_META: Self
RAFS meta data is inlined in the data blob.
Sourcepub const CHUNK_INFO_V2: Self
pub const CHUNK_INFO_V2: Self
Blob chunk information format v2.
Sourcepub const ZRAN: Self
pub const ZRAN: Self
Blob compression information data include context data for zlib random access.
Sourcepub const INLINED_CHUNK_DIGEST: Self
pub const INLINED_CHUNK_DIGEST: Self
Chunk digest array is inlined in the data blob.
Sourcepub const HAS_TAR_HEADER: Self
pub const HAS_TAR_HEADER: Self
Blob has TAR headers to separate contents.
Sourcepub const CAP_TAR_TOC: Self
pub const CAP_TAR_TOC: Self
Data blob are encoded with Tar header and optionally ToC.
It’s also a flag indicating that images are generated with nydus-image v2.2 or newer.
Sourcepub const _V5_NO_EXT_BLOB_TABLE: Self
pub const _V5_NO_EXT_BLOB_TABLE: Self
Rafs V5 image without extended blob table, this is an internal flag.
Sourcepub const IS_CHUNKDICT_GENERATED: Self
pub const IS_CHUNKDICT_GENERATED: Self
Blob is generated with chunkdict.
Sourcepub const IS_SEPARATED_WITH_PREFETCH_FILES: Self
pub const IS_SEPARATED_WITH_PREFETCH_FILES: Self
Blob is generated with separated prefetch files.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> Self
pub const unsafe fn from_bits_unchecked(bits: u32) -> Self
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.