pub struct BlobPrefetchRequest {
pub blob_id: String,
pub offset: u64,
pub len: u64,
}Expand description
Struct representing a blob data prefetching request.
It may help to improve performance for the storage backend to prefetch data in background.
A BlobPrefetchControl object advises to prefetch data range [offset, offset + len) from
blob blob_id. The prefetch operation should be asynchronous, and cache hit for filesystem
read operations should validate data integrity.
Fields
blob_id: StringThe ID of the blob to prefetch data for.
offset: u64Offset into the blob to prefetch data.
len: u64Size of data to prefetch.