BatchContextGenerator

Struct BatchContextGenerator 

pub struct BatchContextGenerator { /* private fields */ }
Struct to generate BatchInflateContext objects for batch chunks.

Implementations

Source

impl BatchContextGenerator

pub fn chunk_data_buf(&self) -> &Vec<u8>

Get the buffer of to be dumped chunk data for batch chunk.

pub fn chunk_data_buf_is_empty(&self) -> bool

Check whether the chunk data buffer is empty.

pub fn chunk_data_buf_len(&self) -> usize

Get the length of chunk data buffer.

pub fn append_chunk_data_buf(&mut self, chunk_data: &[u8])

Append new chunk data to the chunk data buffer.

pub fn clear_chunk_data_buf(&mut self)

Clear the chunk data buffer.

pub fn add_context(&mut self, compressed_size: u32)

Add a batch context for a dumped batch chunk.

pub fn new(batch_size: u32) -> Result<Self>

Create a new instance of BatchInflateContext.

pub fn generate_chunk_info( &mut self, compressed_offset: u64, uncompressed_offset: u64, uncompressed_size: u32, encrypted: bool, ) -> Result<BlobChunkInfoV2Ondisk>

Generate and return a v2 chunk info struct.

pub fn to_vec(&self) -> Result<(Vec<u8>, u32)>

Convert all the batch chunk information to a u8 vector.