BlobCompressionContextHeader

Struct BlobCompressionContextHeader 

pub struct BlobCompressionContextHeader { /* private fields */ }
On disk format for blob compression context table header.

Blob compression context table contains compression information for all chunks in the blob. The compression context table header will be written into the data blob in plaintext mode, and can be used as marker to locate the compression context table. All fields of compression context table header should be encoded in little-endian format.

The compression context table and header are arranged in the data blob as follows:

chunk data | compression context table | [ZRan context table | ZRan dictionary] | compression context table header

Implementations

Source

impl BlobCompressionContextHeader

pub fn has_feature(&self, feature: BlobFeatures) -> bool

Check whether a blob feature is set or not.

pub fn ci_compressor(&self) -> Algorithm

Get compression algorithm to process chunk compression information array.

pub fn set_ci_compressor(&mut self, algo: Algorithm)

Set compression algorithm to process chunk compression information array.

pub fn ci_entries(&self) -> u32

Get number of entries in chunk compression information array.

pub fn set_ci_entries(&mut self, entries: u32)

Set number of entries in chunk compression information array.

pub fn ci_compressed_offset(&self) -> u64

Get offset of compressed chunk compression information array.

pub fn set_ci_compressed_offset(&mut self, offset: u64)

Set offset of compressed chunk compression information array.

pub fn ci_compressed_size(&self) -> u64

Get size of compressed chunk compression information array.

pub fn set_ci_compressed_size(&mut self, size: u64)

Set size of compressed chunk compression information array.

pub fn ci_uncompressed_size(&self) -> u64

Get size of uncompressed chunk compression information array.

pub fn set_ci_uncompressed_size(&mut self, size: u64)

Set size of uncompressed chunk compression information array.

pub fn ci_zran_count(&self) -> u32

Get ZRan context information entry count.

pub fn set_ci_zran_count(&mut self, count: u32)

Set ZRan context information entry count.

pub fn ci_zran_offset(&self) -> u64

Get offset of ZRan context information table.

pub fn set_ci_zran_offset(&mut self, offset: u64)

Set offset of ZRan context information table.

pub fn ci_zran_size(&self) -> u64

Get size of ZRan context information table and dictionary table.

pub fn set_ci_zran_size(&mut self, size: u64)

Set size of ZRan context information table and dictionary table.

pub fn is_4k_aligned(&self) -> bool

Check whether uncompressed chunks are 4k aligned.

pub fn set_aligned(&mut self, aligned: bool)

Set flag indicating whether uncompressed chunks are aligned.

pub fn set_inlined_fs_meta(&mut self, inlined: bool)

Set flag indicating whether RAFS meta is inlined in the data blob.

pub fn set_chunk_info_v2(&mut self, enable: bool)

Set flag indicating whether chunk compression information format v2 is used or not.

pub fn set_ci_zran(&mut self, enable: bool)

Set flag indicating whether it’s a ZRan blob or not.

pub fn set_separate_blob(&mut self, enable: bool)

Set flag indicating whether blob.data and blob.meta are stored in separated blobs.

pub fn set_ci_batch(&mut self, enable: bool)

Set flag indicating whether it’s a blob for batch chunk or not.

pub fn set_inlined_chunk_digest(&mut self, enable: bool)

Set flag indicating whether chunk digest is inlined in the data blob or not.

pub fn set_has_tar_header(&mut self, enable: bool)

Set flag indicating new blob format with tar headers.

pub fn set_has_toc(&mut self, enable: bool)

Set flag indicating new blob format with toc headers.

pub fn set_cap_tar_toc(&mut self, enable: bool)

Set flag indicating having inlined-meta capability.

pub fn set_tarfs(&mut self, enable: bool)

Set flag indicating the blob is for RAFS filesystem in TARFS mode.

pub fn set_encrypted(&mut self, enable: bool)

Set flag indicating the blob is encrypted.

pub fn set_external(&mut self, external: bool)

Set flag indicating the blob is external.

pub fn features(&self) -> u32

Get blob meta feature flags.

pub fn as_bytes(&self) -> &[u8]

Convert the header as an &[u8].

pub fn set_is_chunkdict_generated(&mut self, enable: bool)

Set flag indicating whether it’s a blob for batch chunk or not.