pub enum HttpProxyError {
ParseStringToInteger(ParseIntError),
ParseContentLengthFromHeader(ToStrError),
LocalRequest(Error),
RemoteRequest(ConnectionError),
BuildTokioRuntime(Error),
BuildHttpRequest(Error),
ReadResponseBody(Error),
Transport(Error),
CopyBuffer(Error),
InvalidPath,
ConstructHeader(String),
}Variants
ParseStringToInteger(ParseIntError)
Failed to parse string to integer.
ParseContentLengthFromHeader(ToStrError)
LocalRequest(Error)
Failed to get response from the local http server.
RemoteRequest(ConnectionError)
Failed to get response from the remote http server.
BuildTokioRuntime(Error)
Failed to build the tokio runtime.
BuildHttpRequest(Error)
Failed to build local http request.
ReadResponseBody(Error)
Failed to read the response body.
Transport(Error)
Failed to transport the remote response body.
CopyBuffer(Error)
Failed to copy the buffer.
InvalidPath
Invalid path.
ConstructHeader(String)
Failed to build request header.