pub struct BlobRangeMap { /* private fields */ }Expand description
An implementation of RangeMap to support cache state tracking by using a bitmap file.
The BlobRangeMap is an implementation of RangeMap which uses a bitmap file and atomic
bitmap operations to track readiness state. It creates or opens a file with the name
$blob_id.range_map to record whether a data range has been cached by the blob cache, and
atomic bitmap operations are used to manipulate the state bit. The bitmap file will be persisted
to disk.
Implementations