pub struct BlobStateMap<C, I> { /* private fields */ }Expand description
Adapter structure to enable concurrent chunk readiness manipulating based on a base ChunkMap object.
A base ChunkMap, such as IndexedChunkMap, only
tracks chunk readiness state, but doesn’t support concurrent manipulating of the chunk readiness
state. The BlobStateMap structure acts as an adapter to enable concurrent chunk readiness
state manipulation.
Implementations
Sourceimpl BlobStateMap<BlobRangeMap, u64>
impl BlobStateMap<BlobRangeMap, u64>
Sourcepub fn from_range_map(map: BlobRangeMap) -> Self
pub fn from_range_map(map: BlobRangeMap) -> Self
Create a new instance of BlobStateMap from a BlobRangeMap object.