pub struct DigestedChunkMap { /* private fields */ }Expand description
An implementation of ChunkMap to support chunk state tracking by using
HashSet<RafsDigest>.
The DigestedChunkMap is an implementation of ChunkMap which uses a hash set
(HashSet<chunk_digest>) to record whether a chunk has already been cached by the blob cache.
The implementation is memory and computation heavy, so it is used only to keep backward
compatibility with the previous old nydus bootstrap format. For new clients, please use other
alternative implementations.
Implementations