pub struct IndexedChunkMap { /* private fields */ }Expand description
An implementation of ChunkMap to support chunk state tracking by using a bitmap file.
The IndexedChunkMap is an implementation of ChunkMap which uses a bitmap file and atomic
bitmap operations to track readiness state. It creates or opens a file with the name
$blob_id.chunk_map to record whether a chunk has been cached by the blob cache, and atomic
bitmap operations are used to manipulate the state bit. The bitmap file will be persisted to
disk.
This approach can be used to share chunk ready state between multiple nydusd instances. For example: the bitmap file layout is [0b00000000, 0b00000000], when blobcache calls set_ready(3), the layout should be changed to [0b00010000, 0b00000000].
Implementations